@@ -36,36 +36,42 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '7.4.1-1-n.js';
+gTestfile = '7.4.2-11-n.js';
 
 /**
-   File Name:          7.4.1-1-n.js
-   ECMA Section:       7.4.1
+   File Name:          7.4.2-11-n.js
+   ECMA Section:       7.4.2
 
    Description:
+   The following tokens are ECMAScript keywords and may not be used as
+   identifiers in ECMAScript programs.
 
-   Reserved words cannot be used as identifiers.
+   Syntax
 
-   ReservedWord ::
-   Keyword
-   FutureReservedWord
-   NullLiteral
-   BooleanLiteral
+   Keyword :: one of
+   break          for         new         var
+   continue       function    return      void
+   delete         if          this        while
+   else           in          typeof      with
+
+   This test verifies that the keyword cannot be used as an identifier.
+   Functioinal tests of the keyword may be found in the section corresponding
+   to the function of the keyword.
 
    Author:             christine@netscape.com
    Date:               12 november 1997
 
 */
-var SECTION = "7.4.1-1-n";
+var SECTION = "7.4.1-11-n";
 var VERSION = "ECMA_1";
 startTest();
 var TITLE   = "Keywords";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-DESCRIPTION = "var null = true";
+DESCRIPTION = "var this = true";
 EXPECTED = "error";
 
-new TestCase( SECTION,  "var null = true",     "error",    eval("var null = true") );
+new TestCase( SECTION,  "var this = true",     "error",    eval("var this = true") );
 
 test();
