@@ -36,38 +36,29 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '15.7.3.3-2.js';
+gTestfile = '15.7.3.5-1.js';
 
 /**
-   File Name:          15.7.3.3-2.js
-   ECMA Section:       15.7.3.3 Number.MIN_VALUE
+   File Name:          15.7.3.5-1.js
+   ECMA Section:       15.7.3.5 Number.NEGATIVE_INFINITY
    Description:        All value properties of the Number object should have
    the attributes [DontEnum, DontDelete, ReadOnly]
 
-   this test checks the DontDelete attribute of Number.MIN_VALUE
+   this test checks the  value of Number.NEGATIVE_INFINITY
 
    Author:             christine@netscape.com
    Date:               16 september 1997
 */
-
-
-var SECTION = "15.7.3.3-2";
+var SECTION = "15.7.3.5-1";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Number.MIN_VALUE";
+var TITLE   = "Number.NEGATIVE_INFINITY";
 
-writeHeaderToLog( SECTION + " "+ TITLE );
+writeHeaderToLog( SECTION + " "+TITLE);
 
-var MIN_VAL = 5e-324;
-
-new TestCase(  SECTION,
-	       "delete( Number.MIN_VALUE )",   
-	       false,
-	       eval("delete( Number.MIN_VALUE )") );
-
-new TestCase(  SECTION,
-	       "delete( Number.MIN_VALUE ); Number.MIN_VALUE",
-	       MIN_VAL,
-	       eval("delete( Number.MIN_VALUE );Number.MIN_VALUE") );
+new TestCase(SECTION,  
+	     "Number.NEGATIVE_INFINITY",    
+	     -Infinity, 
+	     Number.NEGATIVE_INFINITY );
 
 test();
